<?php
namespace App\Http\Controllers\Api;

use App\Http\Controllers\BaseController;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Validator;
use Throwable;
use Exception;
use Carbon\Carbon;
use Illuminate\Validation\Rule;
use App\Services\Warn\IWarnService;

class WarnController extends BaseController
{
    private $time;
    private $warnService;

    public function __construct(IWarnService $warnService)
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
        $this->warnService = $warnService;
    }

    /**
     * 新增预警人
     * @return array
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleAdd(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'platform' => 'required|numeric',
            'channel' => 'required|numeric',
            'remarkName' => 'required|string',
            'phone' => 'required|string'
        ]);
        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));

        try {
            $data = $this->warnService->getPeopleAdd($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 预警人列表
     * @return array
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleList(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->warnService->getPeopleList($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 预警人编辑
     * @return array
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleEdit(Request $request)
    {
        $postData = $request->all();
        $validate = Validator::make($postData, [
            'id' => 'required|numeric',
            'platform' => 'required|numeric',
            'channel' => 'required|numeric',
            'remarkName' => 'required|string',
            'phone' => 'required|string'
        ]);
        if ($validate->fails()) return $this->getErrorMsg('1001', config('msg.common.1001'));
        try {
            $data = $this->warnService->getPeopleEdit($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }

    /**
     * 删除预警人
     * @return array
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleDel(Request $request)
    {
        $postData = $request->all();
        try {
            $data = $this->warnService->getPeopleDel($postData);
            return $this->getSuccessMsg($data);
        } catch (Exception $e) {
            return $this->getErrorMsg($e->getCode(), $e->getMessage());
        }
    }


}