<?php
namespace App\Services\Warn;

use App\Services\Warn\IWarnService;
use Carbon\Carbon;
use Exception;
use Illuminate\Support\Facades\DB;
use Illuminate\Support\Str;
use App\Models\WarnPeopleModel;
use Illuminate\Support\Facades\Cache;

class WarnService implements IWarnService
{
    private $time;

    public function __construct()
    {
        $this->time = Carbon::now()->format('Y-m-d H:i:s');
    }

    /**
     * 新增预警人信息
     * @return int
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleAdd($postData)
    {
        if(!preg_match("/^1[3456789]\d{9}$/", $postData['phone'])) throw new Exception(config('msg.common.1013'), 1013);
        if($postData['platform'] < 1 || $postData['channel'] < 1) throw new Exception(config('msg.common.1014'), 1014);
        $verity = WarnPeopleModel::where('platform', $postData['platform'])->where('channel', $postData['channel'])->where('phone',$postData['phone'])->select('id')->first();
        if (!$verity) {
            $row = new WarnPeopleModel();
            $row->platform = $postData['platform'] ?? 0;
            $row->channel = $postData['channel'] ?? 0;
            $row->name = $postData['remarkName'] ?? '';
            $row->phone = $postData['phone'] ?? '';
            $row->op_user = $postData['user'] ?? '';
            $row->remark =  $postData['remark'] ?? '';
            if ($row->save()) return $row->id;
            throw new Exception(config('msg.common.1006'), 1006);
        }
        throw new Exception(config('msg.common.1005'), 1005);
    }


    /**
     * 预警人列表
     * @return araay
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleList($postData)
    {
        $name = $postData['key'] ?? '';
        $platform = $postData['platform'] ?? 0;
        $start = $postData['startTime'] ?? '';
        $end = $postData['endTime'] ?? '';
        $pagePerNum = $postData['pageSize'] ?? 20;
        $currentPage = $postData['page'] ?? 1;

        $lists = WarnPeopleModel::when($name != '', function ($query) use ($name) {
            return $query->where('name', 'like', $name . '%');
        })->when($platform > 0, function ($query) use ($platform) {
            return $query->where('platform',$platform);
        })->when($start != '', function ($query) use ($start) {
            $startTime = date('Y-m-d H:i:s',strtotime($start) - 1);
            return $query->where('created_at', '>',$startTime);
        })->when($end != '', function ($query) use ($end) {
            $endTime = date('Y-m-d H:i:s',strtotime($end) + 1);
            return $query->where('created_at', '<',$endTime);
        })->select('id', 'platform', 'channel', 'name', 'phone','status','op_user', 'created_at')->orderBy('id', 'DESC')->paginate($pagePerNum, ['*'], 'currentPage', $currentPage);
        $array['totalNum'] = $lists->total();
        $array['totalPage'] = $lists->lastPage();
        $platformArr = config(env('ENVIRONMENT') . '.PLATFORM');
        $channelArr = config(env('ENVIRONMENT') . '.CHANNEL');

        foreach ($lists as $list) {
            $tem['id'] = $list->id;
            $tem['platform'] = $platformArr[$list->platform] ?? '';
            $tem['channel'] = $channelArr[$list->channel] ?? '';
            $tem['name'] = $list->name;
            $tem['phone'] = $list->phone;
            $tem['status'] = $list->status;
            $statusName = '停用';
            if($list->status == 1) $statusName = '正常';
            $tem['statusName'] = $statusName;
            $tem['optionUser'] = $list->op_user;
            $tem['createdAt'] = Carbon::parse($list->created_at)->format('Y-m-d H:i:s');
            $array['data'][] = $tem;
        }
        unset($users, $user, $user);
        return $array;
    }

    /**
     * 编辑预警人
     * @return araay
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleEdit($postData)
    {
        if(!preg_match("/^1[3456789]\d{9}$/", $postData['phone'])) throw new Exception(config('msg.common.1013'), 1013);
        if($postData['platform'] < 1 || $postData['channel'] < 1) throw new Exception(config('msg.common.1014'), 1014);
        $verity = WarnPeopleModel::where('id','!=',$postData['id'])->where('platform', $postData['platform'])->where('channel', $postData['channel'])->where('phone',$postData['phone'])->select('id')->first();
        if (!$verity) {
            $row = WarnPeopleModel::find($postData['id']);
            if(!$row) throw new Exception(config('msg.common.1002'), 1002);
            $row->platform = $postData['platform'] ?? 0;
            $row->channel = $postData['channel'] ?? 0;
            $row->name = $postData['remarkName'] ?? '';
            $row->phone = $postData['phone'] ?? '';
            $row->op_user = $postData['user'] ?? '';
            $row->remark =  $postData['remark'] ?? '';
            if ($row->save()) return $row->id;
            throw new Exception(config('msg.common.1006'), 1006);
        }
        throw new Exception(config('msg.common.1005'), 1005);
    }


    /**
     * 删除预警人
     * @return araay
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleDel($postData)
    {
        $list = WarnPeopleModel::where('id', $postData['id'])->first();
        if (!$list) throw new Exception(config('msg.common.1002'), 1002);
        if ($list->delete()) return true;
        throw new Exception(config('msg.common.1003'), 1003);
    }

    /**
     * 设置预警人状态
     * @return araay
     * @date 2021/07/31
     * @author live
     */
    public function getPeopleSetStatus($postData)
    {
        $list = WarnPeopleModel::where('id', $postData['id'])->first();
        if (!$list) throw new Exception(config('msg.common.1002'), 1002);

        if($list->status == $postData['status']) throw new Exception(config('msg.common.1009'), 1009);
        $list->status = $postData['status'];
        $list->addTime = $this->time;
        if ($list->save()) return true;
        throw new Exception(config('msg.common.1003'), 1003);
    }

}